import requests
from .utils import username_to_id

def get_user_groups(username):
    user_id = username_to_id(username)
    if not user_id:
        return None

    g = requests.get(f"https://groups.roblox.com/v1/users/{user_id}/groups/roles")
    g.raise_for_status()
    groups = g.json().get("data", [])

    return [
        {
            "groupId": grp["group"]["id"],
            "groupName": grp["group"]["name"],
            "role": grp["role"]["name"]
        }
        for grp in groups
    ]

def get_owned_groups(username):
    groups = get_user_groups(username)
    if groups is None:
        return None
    return [
        {"groupId": g["groupId"], "groupName": g["groupName"]}
        for g in groups if g["role"].lower() == "owner"
    ]


import requests
from .utils import username_to_id

def get_followers_count(username: str) -> int:
    user_id = username_to_id(username)
    if not user_id:
        return 0
    url = f"https://friends.roblox.com/v1/users/{user_id}/followers/count"
    r = requests.get(url)
    if r.status_code != 200:
        return 0
    return r.json().get("count", 0)

def get_following_count(username: str) -> int:
    user_id = username_to_id(username)
    if not user_id:
        return 0
    url = f"https://friends.roblox.com/v1/users/{user_id}/followings/count"
    r = requests.get(url)
    if r.status_code != 200:
        return 0
    return r.json().get("count", 0)


import requests
from .utils import username_to_id

def get_user_info(username):
    user_id = username_to_id(username)
    if not user_id:
        return None

    u = requests.get(f"https://users.roblox.com/v1/users/{user_id}")
    u.raise_for_status()
    info = u.json()

    return {
        "username": info.get("name"),
        "displayName": info.get("displayName"),
        "userId": info.get("id"),
        "description": info.get("description"),
        "created": info.get("created"),
        "isBanned": info.get("isBanned")
    }


import requests

def username_to_id(username):
    r = requests.post("https://users.roblox.com/v1/usernames/users", json={"usernames": [username]})
    r.raise_for_status()
    data = r.json().get("data", [])
    return data[0]["id"] if data else None


import requests
from .utils import username_to_id

def get_last_location(username: str) -> str | None:
    user_id = username_to_id(username)
    if not user_id:
        return None

    url = "https://presence.roblox.com/v1/presence/users"
    resp = requests.post(url, json={"userIds": [user_id]})
    if resp.status_code != 200:
        return None

    data = resp.json().get("userPresences", [])
    if not data:
        return None

    return data[0].get("lastLocation")


import requests

def get_user_rap(user_id):
    url = f"https://inventory.roblox.com/v1/users/{user_id}/assets/collectibles?sortOrder=Asc&limit=100"
    rap = 0
    cursor = None

    while True:
        params = {"cursor": cursor} if cursor else {}
        r = requests.get(url, params=params)
        if r.status_code != 200:
            break
        data = r.json()
        for item in data.get("data", []):
            rap += item.get("recentAveragePrice", 0)
        cursor = data.get("nextPageCursor")
        if not cursor:
            break

    return rap


import requests
from .utils import username_to_id

def is_premium(username: str) -> bool:
    user_id = username_to_id(username)
    if not user_id:
        return False

    url = f"https://premiumfeatures.roblox.com/v1/users/{user_id}/validate-membership"
    r = requests.get(url)
    if r.status_code != 200:
        return False

    return r.json().get("isPremium", False)


import requests
from .utils import username_to_id

def get_full_body_thumbnail(username: str) -> str:
    user_id = username_to_id(username)
    if not user_id:
        return None
    url = f"https://thumbnails.roblox.com/v1/users/avatar?userIds={user_id}&size=420x420&format=Png&isCircular=false"
    r = requests.get(url)
    data = r.json()
    if "data" in data and len(data["data"]) > 0:
        return data["data"][0]["imageUrl"]
    return None


from .user import get_user_info
from .groups import get_user_groups, get_owned_groups
from .utils import username_to_id
from .rap import get_user_rap
from .thumbnail import get_full_body_thumbnail
from .status import get_last_location
from .friends import get_friends_count
from .email import is_email_verified
from .premium import is_premium
from .followers import get_followers_count, get_following_count

__all__ = [
    "get_user_info",
    "get_user_groups",
    "get_owned_groups",
    "username_to_id",
    "get_user_rap",
    "get_full_body_thumbnail",
    "get_last_location",
    "get_friends_count",
    "is_email_verified",
    "is_premium",
    "get_followers_count",
    "get_following_count"
]